@@ -6,14 +6,13 @@
  * Author:
  *   Nat Friedman (nat@ximian.com)
  *
- * Copyright 2000, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #include <config.h>
 #include <bonobo/bonobo-main.h>
 #include "e-contact.h"
 #include "e-book-listener.h"
-#include "e-book-marshal.h"
 
 #define d(x)
 
@@ -52,6 +51,8 @@ e_book_listener_convert_status (const GNOME_Evolution_Addressbook_CallStatus sta
 		return E_BOOK_ERROR_AUTHENTICATION_FAILED;
 	case GNOME_Evolution_Addressbook_AuthenticationRequired:
 		return E_BOOK_ERROR_AUTHENTICATION_REQUIRED;
+	case GNOME_Evolution_Addressbook_UnsupportedAuthenticationMethod:
+		return E_BOOK_ERROR_UNSUPPORTED_AUTHENTICATION_METHOD;
 	case GNOME_Evolution_Addressbook_TLSNotAvailable:
 		return E_BOOK_ERROR_TLS_NOT_AVAILABLE;
 	case GNOME_Evolution_Addressbook_NoSuchBook:
@@ -374,7 +375,6 @@ impl_BookListener_report_link_status (PortableServer_Servant servant,
 
 static void
 impl_BookListener_report_auth_required (PortableServer_Servant servant,
-				   const CORBA_boolean is_online,
 				   CORBA_Environment *ev)
 {
 	EBookListener *listener = E_BOOK_LISTENER (bonobo_object (servant));
@@ -400,17 +400,17 @@ impl_BookListener_respond_progress (PortableServer_Servant servant,
  * Returns: a new #EBookListener
  */
 EBookListener *
-e_book_listener_new ()
+e_book_listener_new (void)
 {
 	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
 	static PortableServer_POA poa = NULL;
 	EBookListener *listener;
-	
+
 	g_static_mutex_lock (&mutex);
 	if (poa == NULL)
 		poa = bonobo_poa_get_threaded (ORBIT_THREAD_HINT_ON_CONTEXT, _ebook_context, NULL);
 	g_static_mutex_unlock (&mutex);
-	
+
 	listener = g_object_new (E_TYPE_BOOK_LISTENER, "poa", poa, NULL);
 
 	return listener;
@@ -462,7 +462,7 @@ e_book_listener_class_init (EBookListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EBookListenerClass, response),
 			      NULL, NULL,
-			      e_book_marshal_NONE__POINTER,
+			      g_cclosure_marshal_VOID__POINTER,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_POINTER);
 
@@ -492,4 +492,4 @@ BONOBO_TYPE_FUNC_FULL (
 		       EBookListener,
 		       GNOME_Evolution_Addressbook_BookListener,
 		       BONOBO_TYPE_OBJECT,
-		       e_book_listener);
+		       e_book_listener)
