@@ -28,6 +28,7 @@
 #include <gconf/gconf-client.h>
 #include <glib/gi18n-lib.h>
 #include "libedataserver/e-xml-hash-utils.h"
+#include "libedataserver/e-proxy.h"
 #include <libecal/e-cal-recur.h>
 #include <libecal/e-cal-util.h>
 #include <libecal/e-cal-time-util.h>
@@ -46,7 +47,7 @@
 
 #include "e-cal-backend-caldav.h"
 
-#define d(x) x
+#define d(x)
 
 /* in seconds */
 #define DEFAULT_REFRESH_TIME 60
@@ -91,6 +92,7 @@ struct _ECalBackendCalDAVPrivate {
 
 	/* The main soup session  */
 	SoupSession *session;
+	EProxy *proxy;
 
 	/* well, guess what */
 	gboolean read_only;
@@ -201,7 +203,7 @@ caldav_debug_init_once (gpointer data)
 }
 
 static void
-caldav_debug_init ()
+caldav_debug_init (void)
 {
 	static GOnce debug_once = G_ONCE_INIT;
 
@@ -299,7 +301,7 @@ icomp_x_prop_get (icalcomponent *comp, const char *key)
 	}
 
 	if (xprop) {
-		return icalproperty_get_value_as_string (xprop);
+		return icalproperty_get_value_as_string_r (xprop);
 	}
 
 	return NULL;
@@ -311,7 +313,10 @@ e_cal_component_set_href (ECalComponent *comp, const char *href)
 {
 	icalcomponent *icomp;
 
+	g_return_if_fail (href != NULL);
+
 	icomp = e_cal_component_get_icalcomponent (comp);
+	g_return_if_fail (icomp != NULL);
 
 	icomp_x_prop_set (icomp, X_E_CALDAV "HREF", href);
 }
@@ -324,6 +329,7 @@ e_cal_component_get_href (ECalComponent *comp)
 
 	str = NULL;
 	icomp = e_cal_component_get_icalcomponent (comp);
+	g_return_val_if_fail (icomp != NULL, NULL);
 
 	str =  icomp_x_prop_get (icomp, X_E_CALDAV "HREF");
 
@@ -336,11 +342,12 @@ e_cal_component_set_etag (ECalComponent *comp, const char *etag)
 {
 	icalcomponent *icomp;
 
+	g_return_if_fail (etag != NULL);
+
 	icomp = e_cal_component_get_icalcomponent (comp);
+	g_return_if_fail (icomp != NULL);
 
 	icomp_x_prop_set (icomp, X_E_CALDAV "ETAG", etag);
-
-
 }
 
 static char *
@@ -351,6 +358,7 @@ e_cal_component_get_etag (ECalComponent *comp)
 
 	str = NULL;
 	icomp = e_cal_component_get_icalcomponent (comp);
+	g_return_val_if_fail (icomp != NULL, NULL);
 
 	str =  icomp_x_prop_get (icomp, X_E_CALDAV "ETAG");
 
@@ -366,7 +374,7 @@ typedef enum {
 	/* local changes */
 	E_CAL_COMPONENT_LOCALLY_CREATED,
 	E_CAL_COMPONENT_LOCALLY_DELETED,
-	E_CAL_COMPONENT_LOCALLY_MODIFIED,
+	E_CAL_COMPONENT_LOCALLY_MODIFIED
 
 } ECalComponentSyncState;
 
@@ -742,7 +750,6 @@ parse_report_response (SoupMessage *soup_message, CalDAVObject **objs, int *len)
 		xpres = xpath_eval (xpctx,XPATH_STATUS , i + 1);
 		object->status = xp_object_get_status (xpres);
 
-		//dump_xp_object (xpres);
 		if (object->status && object->status != 200) {
 			continue;
 		}
@@ -790,75 +797,6 @@ soup_authenticate (SoupSession  *session,
 		soup_auth_authenticate (auth, priv->username, priv->password);
 }
 
-static gint
-caldav_ignore_host(gconstpointer a, gconstpointer b)
-{
-	gchar *hostname = (gchar*)a,
-	      *ignore = (gchar*)b;
-
-	if (hostname && ignore)
-	  return strcmp(hostname, ignore);
-        return -1;
-}
-
-static void
-caldav_set_session_proxy(ECalBackendCalDAVPrivate *priv)
-{
-	GConfClient *conf_client;
-	SoupURI *uri_base;
-
- 	if (priv->session == NULL)
- 		return;
-
-	uri_base = soup_uri_new (priv->uri);
-	if (uri_base == NULL)
-		return;
-
-	/* set the outbound HTTP proxy, if configuration is set to do so */
-	conf_client = gconf_client_get_default ();
-	if (gconf_client_get_bool (conf_client, "/system/http_proxy/use_http_proxy", NULL)) {
-		char *server, *proxy_uri;
-		int port;
- 		GSList *ignore = gconf_client_get_list (conf_client,
-  							"/system/http_proxy/ignore_hosts",
-  		                                	GCONF_VALUE_STRING, NULL);
-  		if (ignore == NULL ||
-  		    g_slist_find_custom(ignore, uri_base->host, caldav_ignore_host) == NULL) {
-  			server = gconf_client_get_string (conf_client, "/system/http_proxy/host", NULL);
-			port = gconf_client_get_int (conf_client, "/system/http_proxy/port", NULL);
-
-			if (server && server[0]) {
-				SoupURI *suri;
-				if (gconf_client_get_bool (conf_client, "/system/http_proxy/use_authentication", NULL)) {
-					char *user, *password;
-					user = gconf_client_get_string (conf_client,
-									"/system/http_proxy/authentication_user",
-									NULL);
-					password = gconf_client_get_string (conf_client,
-									    "/system/http_proxy/authentication_password",
-									    NULL);
-
-					proxy_uri = g_strdup_printf("http://%s:%s@%s:%d", user, password, server, port);
-					g_free (user);
-					g_free (password);
-				} else
-					proxy_uri = g_strdup_printf ("http://%s:%d", server, port);
-
-				suri = soup_uri_new (proxy_uri);
-				g_object_set (G_OBJECT (priv->session), SOUP_SESSION_PROXY_URI, suri, NULL);
-
-				soup_uri_free (suri);
-				g_free (server);
-				g_free (proxy_uri);
-			}
-		}
- 		g_slist_foreach(ignore, (GFunc) g_free, NULL);
-		g_slist_free(ignore);
-	}
-	soup_uri_free (uri_base);
-}
-
-
 /* ************************************************************************* */
 /* direct CalDAV server access functions */
 
@@ -1063,7 +1001,8 @@ check_calendar_changed_on_server (ECalBackendCalDAV *cbdav)
 		return FALSE;
 
 	doc = xmlNewDoc ((xmlChar *) "1.0");
-	root = xmlNewNode (NULL, (xmlChar *) "propfind");
+	root = xmlNewDocNode (doc, NULL, (xmlChar *) "propfind", NULL);
+	xmlDocSetRootElement (doc, root);
 	nsdav = xmlNewNs (root, (xmlChar *) "DAV:", NULL);
 	ns = xmlNewNs (root, (xmlChar *) "http://calendarserver.org/ns/", (xmlChar *) "CS");
 
@@ -1142,10 +1081,10 @@ caldav_server_list_objects (ECalBackendCalDAV *cbdav, CalDAVObject **objs, int *
 	/* Maybe we should just do a g_strdup_printf here? */
 	/* Prepare request body */
 	doc = xmlNewDoc ((xmlChar *) "1.0");
-	root = xmlNewNode (NULL, (xmlChar *) "calendar-query");
-	nscd = xmlNewNs (root, (xmlChar *) "urn:ietf:params:xml:ns:caldav",
-			 (xmlChar *) "C");
+	root = xmlNewDocNode (doc, NULL, (xmlChar *) "calendar-query", NULL);
+	nscd = xmlNewNs (root, (xmlChar *) "urn:ietf:params:xml:ns:caldav", (xmlChar *) "C");
 	xmlSetNs (root, nscd);
+	xmlDocSetRootElement (doc, root);
 
 	/* Add webdav tags */
 	nsdav = xmlNewNs (root, (xmlChar *) "DAV:", (xmlChar *) "D");
@@ -1227,20 +1166,23 @@ caldav_server_get_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 
 	uri = caldav_generate_uri (cbdav, object->href);
 	message = soup_message_new (SOUP_METHOD_GET, uri);
-	g_free (uri);
-	if (message == NULL)
+	if (message == NULL) {
+		g_free (uri);
 		return GNOME_Evolution_Calendar_NoSuchCal;
+	}
 
 	soup_message_headers_append (message->request_headers,
 				     "User-Agent", "Evolution/" VERSION);
 
 	send_and_handle_redirection (priv->session, message, NULL);
 
-	if (! SOUP_STATUS_IS_SUCCESSFUL (message->status_code)) {
-		result = status_code_to_result (message->status_code, priv);
+	if (!SOUP_STATUS_IS_SUCCESSFUL (message->status_code)) {
+		guint status_code = message->status_code;
 		g_object_unref (message);
-		g_warning ("Could not fetch object from server\n");
-		return result;
+
+		g_warning ("Could not fetch object '%s' from server, status:%d (%s)", uri, status_code, soup_status_get_phrase (status_code) ? soup_status_get_phrase (status_code) : "Unknown code");
+		g_free (uri);
+		return status_code_to_result (status_code, priv);
 	}
 
 	hdr = soup_message_headers_get (message->response_headers, "Content-Type");
@@ -1248,7 +1190,8 @@ caldav_server_get_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 	if (hdr == NULL || g_ascii_strncasecmp (hdr, "text/calendar", 13)) {
 		result = GNOME_Evolution_Calendar_InvalidObject;
 		g_object_unref (message);
-		g_warning ("Object to fetch not of type text/calendar");
+		g_warning ("Object to fetch '%s' not of type text/calendar", uri);
+		g_free (uri);
 		return result;
 	}
 
@@ -1258,8 +1201,9 @@ caldav_server_get_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 		g_free (object->etag);
 		object->etag = quote_etag (hdr);
 	} else if (!object->etag) {
-		g_warning ("UUHH no ETag, now that's bad!");
+		g_warning ("UUHH no ETag, now that's bad! (at '%s')", uri);
 	}
+	g_free (uri);
 
 	g_free (object->cdata);
 	object->cdata = g_strdup (message->response_body->data);
@@ -1328,15 +1272,25 @@ caldav_server_put_object (ECalBackendCalDAV *cbdav, CalDAVObject *object)
 	result = status_code_to_result (message->status_code, priv);
 
 	if (result == GNOME_Evolution_Calendar_Success) {
-		hdr = soup_message_headers_get (message->response_headers,
-						"ETag");
-	}
+		hdr = soup_message_headers_get (message->response_headers, "ETag");
+		if (hdr != NULL) {
+			g_free (object->etag);
+			object->etag = quote_etag (hdr);
+		} else {
+			/* no ETag header returned, check for it with a GET */
+			hdr = soup_message_headers_get (message->response_headers, "Location");
+			if (hdr) {
+				/* reflect possible href change first */
+				char *file = strrchr (hdr, '/');
 
-	if (hdr != NULL) {
-		g_free (object->etag);
-		object->etag = quote_etag (hdr);
-	} else {
-		g_warning ("Ups no Etag in put response");
+				if (file) {
+					g_free (object->href);
+					object->href = soup_uri_encode (file + 1, NULL);
+				}
+			}
+
+			result = caldav_server_get_object (cbdav, object);
+		}
 	}
 
 	g_object_unref (message);
@@ -1401,10 +1355,8 @@ synchronize_object (ECalBackendCalDAV *cbdav,
 	res  = TRUE;
 	result  = caldav_server_get_object (cbdav, object);
 
-	if (result != GNOME_Evolution_Calendar_Success) {
-		g_warning ("Could not fetch object from server");
+	if (result != GNOME_Evolution_Calendar_Success)
 		return FALSE;
-	}
 
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
 
@@ -1545,6 +1497,8 @@ synchronize_cache (ECalBackendCalDAV *cbdav)
 
 		if (res) {
 			cobjs = g_list_remove (cobjs, ccomp);
+			if (ccomp)
+				g_object_unref (ccomp);
 		}
 
 		caldav_object_free (object, FALSE);
@@ -1768,6 +1722,26 @@ initialize_backend (ECalBackendCalDAV *cbdav)
 		priv->uri = g_strdup (uri);
 	}
 
+	if (priv->uri) {
+		SoupURI *suri = soup_uri_new (priv->uri);
+
+		/* properly encode uri */
+		if (suri && suri->path) {
+			char *tmp = soup_uri_encode (suri->path, NULL);
+			char *path = soup_uri_normalize (tmp, "/");
+
+			soup_uri_set_path (suri, path);
+
+			g_free (tmp);
+			g_free (path);
+			g_free (priv->uri);
+
+			priv->uri = soup_uri_to_string (suri, FALSE);
+		}
+
+		soup_uri_free (suri);
+	}
+
 	/* remove trailing slashes... */
 	len = strlen (priv->uri);
 	while (len--) {
@@ -1833,6 +1807,23 @@ out:
 	return result;
 }
 
+static void
+proxy_settings_changed (EProxy *proxy, gpointer user_data)
+{
+	SoupURI *proxy_uri = NULL;
+	ECalBackendCalDAVPrivate *priv = (ECalBackendCalDAVPrivate *) user_data;
+
+	if (!priv || !priv->uri || !priv->session)
+		return;
+
+	/* use proxy if necessary */
+	if (e_proxy_require_proxy_for_uri (proxy, priv->uri)) {
+		proxy_uri = e_proxy_peek_uri_for (proxy, priv->uri);
+	}
+
+	g_object_set (priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+}
+
 static ECalBackendSyncStatus
 caldav_do_open (ECalBackendSync *backend,
 		EDataCal        *cal,
@@ -1886,7 +1877,7 @@ caldav_do_open (ECalBackendSync *backend,
 
 	if (priv->mode == CAL_MODE_REMOTE) {
 		/* set forward proxy */
-		caldav_set_session_proxy (priv);
+		proxy_settings_changed (priv->proxy, priv);
 
 		status = caldav_server_open_calendar (cbdav);
 
@@ -1970,7 +1961,8 @@ pack_cobj (ECalBackendCalDAV *cbdav, ECalComponent *ecomp)
 		calcomp = icalcomponent_new_clone (icomp);
 	}
 
-	objstr = icalcomponent_as_ical_string (calcomp);
+	objstr = icalcomponent_as_ical_string_r (calcomp);
+	icalcomponent_free (calcomp);
 
 	g_assert (objstr);
 
@@ -2068,7 +2060,6 @@ caldav_create_object (ECalBackendSync  *backend,
 
 	if (online) {
 		CalDAVObject object;
-		const char *id = NULL;
 
 		href = e_cal_component_gen_href (comp);
 		
@@ -2077,12 +2068,12 @@ caldav_create_object (ECalBackendSync  *backend,
 		object.cdata = pack_cobj (cbdav, comp);
 
 		status = caldav_server_put_object (cbdav, &object);
+		if (status == GNOME_Evolution_Calendar_Success) {
+			e_cal_component_set_href (comp, object.href);
+			e_cal_component_set_etag (comp, object.etag);
+		}
 
-		e_cal_component_get_uid (comp, &id);
-		e_cal_component_set_href (comp, object.href);
-		e_cal_component_set_etag (comp, object.etag);
 		caldav_object_free (&object, FALSE);
-
 	} else {
 		/* mark component as out of synch */
 		e_cal_component_set_synch_state (comp,
@@ -2164,11 +2155,12 @@ caldav_modify_object (ECalBackendSync  *backend,
 		object.cdata = pack_cobj (cbdav, comp);
 
 		status = caldav_server_put_object (cbdav, &object);
+		if (status == GNOME_Evolution_Calendar_Success) {
+			e_cal_component_set_href (comp, object.href);
+			e_cal_component_set_etag (comp, object.etag);
+		}
 
-		e_cal_component_set_href (comp, object.href);
-		e_cal_component_set_etag (comp, object.etag);
 		caldav_object_free (&object, FALSE);
-
 	} else {
 		/* mark component as out of synch */
 		e_cal_component_set_synch_state (comp,
@@ -2247,8 +2239,10 @@ caldav_remove_object (ECalBackendSync  *backend,
 			caldav_object.cdata = pack_cobj (cbdav, cache_comp);
 
 			status = caldav_server_put_object (cbdav, &caldav_object);
-			e_cal_component_set_href (cache_comp, caldav_object.href);
-			e_cal_component_set_etag (cache_comp, caldav_object.etag);
+			if (status == GNOME_Evolution_Calendar_Success) {
+				e_cal_component_set_href (cache_comp, caldav_object.href);
+				e_cal_component_set_etag (cache_comp, caldav_object.etag);
+			}
 		} else
 			status = caldav_server_delete_object (cbdav, &caldav_object);
 
@@ -2344,6 +2338,7 @@ process_object (ECalBackendCalDAV   *cbdav,
 	char                     *rid;
 	char                     *ostr;
 	char                     *oostr;
+	gboolean                  is_declined;
 
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
 	backend = E_CAL_BACKEND (cbdav);
@@ -2374,6 +2369,7 @@ process_object (ECalBackendCalDAV   *cbdav,
 		case ICAL_METHOD_REQUEST:
 		case ICAL_METHOD_REPLY:
 
+		is_declined = e_cal_backend_user_declined (e_cal_component_get_icalcomponent (ecomp));
 		if (online) {
 			CalDAVObject object = { NULL, };
 
@@ -2387,21 +2383,34 @@ process_object (ECalBackendCalDAV   *cbdav,
 				object.href  = href;
 				object.etag  = etag;
 
-			} else {
+			} else if (!is_declined) {
 				object.href = e_cal_component_gen_href (ecomp);
 			}
 
-			object.cdata = pack_cobj (cbdav, ecomp);
-			status = caldav_server_put_object (cbdav, &object);
-			e_cal_component_set_href (ecomp, object.href);
-			e_cal_component_set_etag (ecomp, object.etag);
-			caldav_object_free (&object, FALSE);
+			if (!is_declined || ccomp) {
+				if (!is_declined) {
+					object.cdata = pack_cobj (cbdav, ecomp);
+					status = caldav_server_put_object (cbdav, &object);
+
+					if (status == GNOME_Evolution_Calendar_Success) {
+						e_cal_component_set_href (ecomp, object.href);
+						e_cal_component_set_etag (ecomp, object.etag);
+					}
+				} else {
+					object.cdata = NULL;
+					status = caldav_server_delete_object (cbdav, &object);
+				}
+				caldav_object_free (&object, FALSE);
+			}
 		} else {
-			ECalComponentSyncState sstate;
+			ECalComponentSyncState sstate = E_CAL_COMPONENT_IN_SYNCH;
 
 			if (ccomp) {
-				sstate = E_CAL_COMPONENT_LOCALLY_MODIFIED;
-			} else {
+				if (!is_declined)
+					sstate = E_CAL_COMPONENT_LOCALLY_MODIFIED;
+				else
+					sstate = E_CAL_COMPONENT_LOCALLY_DELETED;
+			} else if (!is_declined) {
 				sstate = E_CAL_COMPONENT_LOCALLY_CREATED;
 			}
 
@@ -2413,18 +2422,21 @@ process_object (ECalBackendCalDAV   *cbdav,
 			break;
 		}
 
-		e_cal_backend_cache_put_component (priv->cache, ecomp);
+		if (!is_declined)
+			e_cal_backend_cache_put_component (priv->cache, ecomp);
+		else
+			e_cal_backend_cache_remove_component (priv->cache, uid, rid);
 
 		if (ccomp) {
-
-			e_cal_backend_notify_object_modified (backend,
-							      ostr,
-							      oostr);
-
-		} else {
-
-			e_cal_backend_notify_object_created (backend,
-							     ostr);
+			if (!is_declined)
+				e_cal_backend_notify_object_modified (backend, ostr, oostr);
+			else {
+				id = e_cal_component_get_id (ccomp);
+				e_cal_backend_notify_object_removed (E_CAL_BACKEND (backend), id, oostr, NULL);
+				e_cal_component_free_id (id);
+			}
+		} else if (!is_declined) {
+			e_cal_backend_notify_object_created (backend, ostr);
 		}
 
 		break;
@@ -2472,11 +2484,11 @@ process_object (ECalBackendCalDAV   *cbdav,
 							      rid);
 
 			id = e_cal_component_get_id (ccomp);
-
 			e_cal_backend_notify_object_removed (E_CAL_BACKEND (backend),
 							     id,
 							     oostr,
 							     ostr);
+			e_cal_component_free_id (id);
 			break;
 
 		default:
@@ -2485,7 +2497,6 @@ process_object (ECalBackendCalDAV   *cbdav,
 			break;
 	}
 
-	g_object_unref (ecomp);
 	g_free (ostr);
 	g_free (oostr);
 	g_free (rid);
@@ -2536,9 +2547,13 @@ caldav_receive_objects (ECalBackendSync *backend,
 
 	if (status == GNOME_Evolution_Calendar_Success) {
 		for (iter = timezones; iter; iter = iter->next) {
-			icaltimezone *zone = iter->data;
+			icaltimezone *zone = icaltimezone_new ();
+
+			if (icaltimezone_set_component (zone, iter->data))
+				e_cal_backend_cache_put_timezone (priv->cache, zone);
+			else
+				icalcomponent_free (iter->data);
 
-			e_cal_backend_cache_put_timezone (priv->cache, zone);
 			icaltimezone_free (zone, TRUE);
 		}
 	}
@@ -2693,7 +2708,7 @@ caldav_get_timezone (ECalBackendSync  *backend,
 		return GNOME_Evolution_Calendar_InvalidObject;
 	}
 
-	*object = icalcomponent_as_ical_string (icalcomp);
+	*object = icalcomponent_as_ical_string_r (icalcomp);
 
 	return GNOME_Evolution_Calendar_Success;
 }
@@ -3014,7 +3029,7 @@ caldav_internal_get_timezone (ECalBackend *backend,
 /* ************************************************************************* */
 /* ***************************** GObject Foo ******************************* */
 
-G_DEFINE_TYPE (ECalBackendCalDAV, e_cal_backend_caldav, E_TYPE_CAL_BACKEND_SYNC);
+G_DEFINE_TYPE (ECalBackendCalDAV, e_cal_backend_caldav, E_TYPE_CAL_BACKEND_SYNC)
 
 static void
 e_cal_backend_caldav_dispose (GObject *object)
@@ -3042,6 +3057,7 @@ e_cal_backend_caldav_dispose (GObject *object)
 	}
 
 	g_object_unref (priv->session);
+	g_object_unref (priv->proxy);
 
 	g_free (priv->username);
 	g_free (priv->password);
@@ -3083,7 +3099,6 @@ e_cal_backend_caldav_finalize (GObject *object)
 		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
-
 static void
 e_cal_backend_caldav_init (ECalBackendCalDAV *cbdav)
 {
@@ -3091,6 +3106,9 @@ e_cal_backend_caldav_init (ECalBackendCalDAV *cbdav)
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
 
 	priv->session = soup_session_sync_new ();
+	priv->proxy = e_proxy_new ();
+	e_proxy_setup_proxy (priv->proxy);
+	g_signal_connect (priv->proxy, "changed", G_CALLBACK (proxy_settings_changed), priv);
 
 	if (G_UNLIKELY (caldav_debug_show (DEBUG_MESSAGE)))
 		caldav_debug_setup (priv->session);
