@@ -1,7 +1,6 @@
 /* Evolution calendar client interface object
  *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Federico Mena-Quintero <federico@ximian.com>
  *          Rodrigo Moya <rodrigo@ximian.com>
@@ -703,7 +702,7 @@ e_data_cal_init (EDataCal *cal, EDataCalClass *klass)
 						    (GDestroyNotify) bonobo_object_unref);
 }
 
-BONOBO_TYPE_FUNC_FULL (EDataCal, GNOME_Evolution_Calendar_Cal, PARENT_TYPE, e_data_cal);
+BONOBO_TYPE_FUNC_FULL (EDataCal, GNOME_Evolution_Calendar_Cal, PARENT_TYPE, e_data_cal)
 
 /**
  * e_data_cal_notify_read_only:
