@@ -713,6 +713,8 @@ co_type_register(CamelType parent, const char * name,
 
 	TYPE_LOCK();
 
+	camel_type_init(); /* has a static boolean itself */
+
 	/* Have to check creation, it might've happened in another thread before we got here */
 	klass = g_hash_table_lookup(type_table, name);
 	if (klass != NULL) {
@@ -1910,13 +1912,13 @@ object_class_dump_tree_rec(CamelType root, int depth)
 #ifdef CAMEL_OBJECT_TRACK_INSTANCES
 		o = root->instances;
 		while (o) {
-			printf("%s instance %p [%d]\n", p, o, o->ref_count);
+			printf("%s instance %p [%d]\n", p, (gpointer) o, o->ref_count);
 			/* todo: should lock hooks while it scans them */
 			if (o->hooks) {
 				CamelHookPair *pair = o->hooks->list;
 
 				while (pair) {
-					printf("%s  hook '%s' func %p data %p\n", p, pair->name, pair->func.event, pair->data);
+					printf("%s  hook '%s' func %p data %p\n", p, pair->name, (gpointer) pair->func.event, (gpointer) pair->data);
 					pair = pair->next;
 				}
 			}
