@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2003 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -32,9 +32,8 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <libedataserver/e-msgport.h>
-
 #include "camel-block-file.h"
+#include "camel-list-utils.h"
 #include "camel-partition-table.h"
 
 /* Do we synchronously write table updates - makes the
@@ -64,7 +63,7 @@ camel_partition_table_init(CamelPartitionTable *cpi)
 {
 	struct _CamelPartitionTablePrivate *p;
 
-	e_dlist_init(&cpi->partition);
+	camel_dlist_init(&cpi->partition);
 
 	p = cpi->priv = g_malloc0(sizeof(*cpi->priv));
 	pthread_mutex_init(&p->lock, NULL);
@@ -79,7 +78,7 @@ camel_partition_table_finalise(CamelPartitionTable *cpi)
 	p = cpi->priv;
 
 	if (cpi->blocks) {
-		while ((bl = (CamelBlock *)e_dlist_remhead(&cpi->partition))) {
+		while ((bl = (CamelBlock *)camel_dlist_remhead(&cpi->partition))) {
 			camel_block_file_sync_block(cpi->blocks, bl);
 			camel_block_file_unref_block(cpi->blocks, bl);
 		}
@@ -87,9 +86,9 @@ camel_partition_table_finalise(CamelPartitionTable *cpi)
 
 		camel_object_unref((CamelObject *)cpi->blocks);
 	}
-
+	
 	pthread_mutex_destroy(&p->lock);
-
+	
 	g_free(p);
 
 }
@@ -98,7 +97,7 @@ CamelType
 camel_partition_table_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-
+	
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_object_get_type(), "CamelPartitionTable",
 					   sizeof (CamelPartitionTable),
@@ -108,7 +107,7 @@ camel_partition_table_get_type(void)
 					   (CamelObjectInitFunc) camel_partition_table_init,
 					   (CamelObjectFinalizeFunc) camel_partition_table_finalise);
 	}
-
+	
 	return type;
 }
 
@@ -213,7 +212,7 @@ CamelPartitionTable *camel_partition_table_new(struct _CamelBlockFile *bs, camel
 		d(printf("Adding partition block, used = %d, hashid = %08x\n", ptb->used, ptb->partition[0].hashid));
 
 		/* if we have no data, prime initial block */
-		if (ptb->used == 0 && e_dlist_empty(&cpi->partition) && ptb->next == 0) {
+		if (ptb->used == 0 && camel_dlist_empty(&cpi->partition) && ptb->next == 0) {
 			pblock = camel_block_file_new_block(bs);
 			if (pblock == NULL) {
 				camel_block_file_unref_block(bs, block);
@@ -234,7 +233,7 @@ CamelPartitionTable *camel_partition_table_new(struct _CamelBlockFile *bs, camel
 
 		root = ptb->next;
 		camel_block_file_detach_block(bs, block);
-		e_dlist_addtail(&cpi->partition, (EDListNode *)block);
+		camel_dlist_addtail(&cpi->partition, (CamelDListNode *)block);
 	} while (root);
 
 	return cpi;
@@ -250,9 +249,9 @@ camel_partition_table_sync(CamelPartitionTable *cpi)
 {
 	CamelBlock *bl, *bn;
 	int ret = 0;
-
+	
 	CAMEL_PARTITION_TABLE_LOCK(cpi, lock);
-
+	
 	if (cpi->blocks) {
 		bl = (CamelBlock *)cpi->partition.head;
 		bn = bl->next;
@@ -308,7 +307,7 @@ camel_key_t camel_partition_table_lookup(CamelPartitionTable *cpi, const char *k
 	}
 
 	CAMEL_PARTITION_TABLE_UNLOCK(cpi, lock);
-
+	
 	camel_block_file_unref_block(cpi->blocks, block);
 
 	return keyid;
@@ -325,7 +324,7 @@ void camel_partition_table_remove(CamelPartitionTable *cpi, const char *key)
 	hashid = hash_key(key);
 
 	CAMEL_PARTITION_TABLE_LOCK(cpi, lock);
-
+	
 	ptblock = find_partition(cpi, hashid, &index);
 	if (ptblock == NULL) {
 		CAMEL_PARTITION_TABLE_UNLOCK(cpi, lock);
@@ -344,7 +343,7 @@ void camel_partition_table_remove(CamelPartitionTable *cpi, const char *key)
 		if (pkb->keys[i].hashid == hashid) {
 			/* !! need to: lookup and compare string value */
 			/* get_key() if key == key ... */
-
+			
 			/* remove this key */
 			pkb->used--;
 			for (;i<pkb->used;i++) {
@@ -357,7 +356,7 @@ void camel_partition_table_remove(CamelPartitionTable *cpi, const char *key)
 	}
 
 	CAMEL_PARTITION_TABLE_UNLOCK(cpi, lock);
-
+	
 	camel_block_file_unref_block(cpi->blocks, block);
 }
 
@@ -626,9 +625,9 @@ camel_key_table_finalise(CamelKeyTable *ki)
 		camel_block_file_sync(ki->blocks);
 		camel_object_unref((CamelObject *)ki->blocks);
 	}
-
+	
 	pthread_mutex_destroy(&p->lock);
-
+	
 	g_free(p);
 
 }
@@ -637,7 +636,7 @@ CamelType
 camel_key_table_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-
+	
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_object_get_type(), "CamelKeyTable",
 					   sizeof (CamelKeyTable),
@@ -647,7 +646,7 @@ camel_key_table_get_type(void)
 					   (CamelObjectInitFunc) camel_key_table_init,
 					   (CamelObjectFinalizeFunc) camel_key_table_finalise);
 	}
-
+	
 	return type;
 }
 
@@ -761,7 +760,15 @@ camel_key_table_add(CamelKeyTable *ki, const char *key, camel_block_t data, unsi
 
 	kblast->used++;
 
+#if 0
 	g_assert(kblast->used < 127);
+#else
+	if (kblast->used >=127) {
+		g_warning("Invalid value for used %d\n", kblast->used);
+		return 0;
+	}
+#endif
+
 
 	camel_block_file_touch_block(ki->blocks, last);
 	camel_block_file_unref_block(ki->blocks, last);
@@ -826,8 +833,15 @@ camel_key_table_set_flags(CamelKeyTable *ki, camel_key_t keyid, unsigned int fla
 		return;
 	kb = (CamelKeyBlock *)&bl->data;
 
-	g_assert(kb->used < 127);
+#if 0
+	g_assert(kb->used < 127); /* this should be more accurate */
 	g_assert(index < kb->used);
+#else
+	if (kb->used >=127 || index >= kb->used) {
+		g_warning("Block %x: Invalid index or content: index %d used %d\n", blockid, index, kb->used);
+		return ;
+	}
+#endif
 
 	CAMEL_KEY_TABLE_LOCK(ki, lock);
 
@@ -931,7 +945,7 @@ camel_key_table_next(CamelKeyTable *ki, camel_key_t next, char **keyp, unsigned
 	do {
 		blockid =  next & (~(CAMEL_BLOCK_SIZE-1));
 		index = next & (CAMEL_BLOCK_SIZE-1);
-
+		
 		bl = camel_block_file_get_block(ki->blocks, blockid);
 		if (bl == NULL) {
 			CAMEL_KEY_TABLE_UNLOCK(ki, lock);
