@@ -34,6 +34,7 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
+#include "camel-db.h"
 #include "camel-debug.h"
 #include "camel-exception.h"
 #include "camel-folder.h"
@@ -159,9 +160,14 @@ camel_store_finalize (CamelObject *object)
 	
 	g_static_rec_mutex_free (&store->priv->folder_lock);
 
-	if (store->cdb) {
-		camel_db_close (store->cdb);
-		store->cdb = NULL;
+	if (store->cdb_r) {
+		camel_db_close (store->cdb_r);
+		store->cdb_r = NULL;
+	}
+
+	if (store->cdb_w) {
+		camel_db_close (store->cdb_w);
+		store->cdb_w = NULL;
 	}
 
 	g_free (store->priv);
@@ -228,19 +234,22 @@ construct (CamelService *service, CamelSession *session,
 
 	g_free (store_path);
 
-	store->cdb = camel_db_open (store_db_path, ex);
-	printf("store_db_path %s\n", store_db_path);
+	/* This is for reading from the store */
+	store->cdb_r = camel_db_open (store_db_path, ex);
+	if (camel_debug("sqlite"))
+		printf("store_db_path %s\n", store_db_path);
 	if (camel_exception_is_set (ex)) {
 		char *store_path;
 		
-		g_print ("Failure for store_db_path : [%s]\n", store_db_path);
+		if (camel_debug("sqlite"))
+			g_print ("Failure for store_db_path : [%s]\n", store_db_path);
 		g_free (store_db_path);		
 
 		store_path =  camel_session_get_storage_path (session, service, ex);
 		store_db_path = g_build_filename (store_path, CAMEL_DB_FILE, NULL);
 		g_free (store_path);
 		camel_exception_clear(ex);
-		store->cdb = camel_db_open (store_db_path, ex);
+		store->cdb_r = camel_db_open (store_db_path, ex);
 		if (camel_exception_is_set (ex)) {
 			g_print("Retry with %s failed\n", store_db_path);
 			g_free(store_db_path);
@@ -250,13 +259,15 @@ construct (CamelService *service, CamelSession *session,
 	}
 	g_free (store_db_path);
 
-	if (camel_db_create_folders_table (store->cdb, ex))
-		printf ("something went wrong terribly\n");
+	if (camel_db_create_folders_table (store->cdb_r, ex))
+		g_warning ("something went wrong terribly during db creation \n");
 	else
-		printf ("folders table succesfully created \n");
+		d(printf ("folders table successfully created \n"));
 
 	if (camel_exception_is_set (ex))
 		return;
+	/* This is for writing to the store */
+	store->cdb_w = camel_db_clone (store->cdb_r, ex);
 
 	if (camel_url_get_param(url, "filter"))
 		store->flags |= CAMEL_STORE_FILTER_INBOX;
@@ -283,7 +294,7 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
  *
  * Get a specific folder object from the store by name.
  *
- * Returns: the folder corresponding to the path @folder_name.
+ * Returns: the folder corresponding to the path @folder_name or %NULL.
  **/
 CamelFolder *
 camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
@@ -311,6 +322,21 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 	}
 
 	if (!folder) {
+
+		if (flags & CAMEL_STORE_IS_MIGRATING) {
+				if ((store->flags & CAMEL_STORE_VTRASH) && strcmp(folder_name, CAMEL_VTRASH_NAME) == 0) {
+						if (store->folders) 
+								camel_object_bag_abort(store->folders, folder_name);
+						return NULL;
+				}
+
+				if ((store->flags & CAMEL_STORE_VJUNK) && strcmp(folder_name, CAMEL_VJUNK_NAME) == 0) {
+						if (store->folders) 
+								camel_object_bag_abort(store->folders, folder_name);
+						return NULL;
+				}
+		}
+
 		if ((store->flags & CAMEL_STORE_VTRASH) && strcmp(folder_name, CAMEL_VTRASH_NAME) == 0) {
 			folder = CS_CLASS(store)->get_trash(store, ex);
 		} else if ((store->flags & CAMEL_STORE_VJUNK) && strcmp(folder_name, CAMEL_VJUNK_NAME) == 0) {
@@ -382,7 +408,7 @@ create_folder (CamelStore *store, const char *parent_name,
  * @parent_name can be %NULL to create a new top-level folder.
  *
  * Returns: info about the created folder, which the caller must
- * free with #camel_store_free_folder_info
+ * free with #camel_store_free_folder_info, or %NULL.
  **/
 CamelFolderInfo *
 camel_store_create_folder (CamelStore *store, const char *parent_name,
@@ -468,6 +494,11 @@ camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelExce
 
 	CS_CLASS(store)->delete_folder(store, folder_name, &local);
 
+	/* ignore 'no such table' errors */
+	if (camel_exception_is_set (&local) && camel_exception_get_description (&local) &&
+	    g_ascii_strncasecmp (camel_exception_get_description (&local), "no such table", 13) == 0)
+		camel_exception_clear (&local);
+
 	if (!camel_exception_is_set(&local))
 		cs_delete_cached_folder(store, folder_name);
 	else {
@@ -546,40 +577,42 @@ camel_store_rename_folder (CamelStore *store, const char *old_namein, const char
 	CS_CLASS (store)->rename_folder (store, old_name, new_name, ex);
 
 	/* If it worked, update all open folders/unlock them */
-	if (folders && !camel_exception_is_set(ex)) {
-		guint32 flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE;
-		CamelRenameInfo reninfo;
+	if (folders) {
+		if (!camel_exception_is_set(ex)) {
+			guint32 flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE;
+			CamelRenameInfo reninfo;
 
-		for (i=0;i<folders->len;i++) {
-			char *new;
+			for (i=0;i<folders->len;i++) {
+				char *new;
 
-			folder = folders->pdata[i];
+				folder = folders->pdata[i];
 
-			new = g_strdup_printf("%s%s", new_name, folder->full_name+strlen(old_name));
-			camel_object_bag_rekey(store->folders, folder, new);
-			camel_folder_rename(folder, new);
-			g_free(new);
+				new = g_strdup_printf("%s%s", new_name, folder->full_name+strlen(old_name));
+				camel_object_bag_rekey(store->folders, folder, new);
+				camel_folder_rename(folder, new);
+				g_free(new);
 
-			CAMEL_FOLDER_REC_UNLOCK(folder, lock);
-			camel_object_unref(folder);
-		}
+				CAMEL_FOLDER_REC_UNLOCK(folder, lock);
+				camel_object_unref(folder);
+			}
 
-		/* Emit renamed signal */
-		if (store->flags & CAMEL_STORE_SUBSCRIPTIONS)
-			flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
+			/* Emit renamed signal */
+			if (store->flags & CAMEL_STORE_SUBSCRIPTIONS)
+				flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
 		
-		reninfo.old_base = (char *)old_name;
-		reninfo.new = ((CamelStoreClass *)((CamelObject *)store)->klass)->get_folder_info(store, new_name, flags, ex);
-		if (reninfo.new != NULL) {
-			camel_object_trigger_event (store, "folder_renamed", &reninfo);
-			((CamelStoreClass *)((CamelObject *)store)->klass)->free_folder_info(store, reninfo.new);
-		}
-	} else {
-		/* Failed, just unlock our folders for re-use */
-		for (i=0;i<folders->len;i++) {
-			folder = folders->pdata[i];
-			CAMEL_FOLDER_REC_UNLOCK(folder, lock);
-			camel_object_unref(folder);
+			reninfo.old_base = (char *)old_name;
+			reninfo.new = ((CamelStoreClass *)((CamelObject *)store)->klass)->get_folder_info(store, new_name, flags, ex);
+			if (reninfo.new != NULL) {
+				camel_object_trigger_event (store, "folder_renamed", &reninfo);
+				((CamelStoreClass *)((CamelObject *)store)->klass)->free_folder_info(store, reninfo.new);
+			}
+		} else {
+			/* Failed, just unlock our folders for re-use */
+			for (i=0;i<folders->len;i++) {
+				folder = folders->pdata[i];
+				CAMEL_FOLDER_REC_UNLOCK(folder, lock);
+				camel_object_unref(folder);
+			}
 		}
 	}
 
@@ -684,6 +717,17 @@ camel_store_get_junk (CamelStore *store, CamelException *ex)
 		return camel_store_get_folder(store, CAMEL_VJUNK_NAME, 0, ex);
 }
 
+/**
+ * ignore_no_such_table_exception:
+ * Clears the exception 'ex' when it's the 'no such table' exception.
+ **/
+static void
+ignore_no_such_table_exception (CamelException *ex)
+{
+	if (ex && camel_exception_is_set (ex) && g_ascii_strncasecmp (camel_exception_get_description (ex), "no such table", 13) == 0)
+		camel_exception_clear (ex);
+}
+
 static void
 store_sync (CamelStore *store, int expunge, CamelException *ex)
 {
@@ -700,9 +744,10 @@ store_sync (CamelStore *store, int expunge, CamelException *ex)
 		for (i=0;i<folders->len;i++) {
 			folder = folders->pdata[i];
 			if (!CAMEL_IS_VEE_FOLDER(folder)
-			    && !camel_exception_is_set(&x))
+			    && !camel_exception_is_set(&x)) {
 				camel_folder_sync(folder, expunge, &x);
-			else if (CAMEL_IS_VEE_FOLDER(folder))
+				ignore_no_such_table_exception (&x);
+			} else if (CAMEL_IS_VEE_FOLDER(folder))
 				camel_vee_folder_sync_headers(folder, NULL); /* Literally don't care of vfolder exceptions */
 			camel_object_unref(folder);
 		}
@@ -839,7 +884,7 @@ dump_fi(CamelFolderInfo *fi, int depth)
  * counts is to both open the folder and invoke refresh_info() it.
  *
  * Returns: a #CamelFolderInfo tree, which must be freed with
- * #camel_store_free_folder_info
+ * #camel_store_free_folder_info, or %NULL.
  **/
 CamelFolderInfo *
 camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelException *ex)
@@ -882,13 +927,17 @@ free_folder_info (CamelStore *store, CamelFolderInfo *fi)
  * @store: a #CamelStore object
  * @fi: a #CamelFolderInfo as gotten via #camel_store_get_folder_info
  *
- * Frees the data returned by #camel_store_get_folder_info
+ * Frees the data returned by #camel_store_get_folder_info. If @fi is %NULL,
+ * nothing is done, the routine simply returns.
  **/
 void
 camel_store_free_folder_info (CamelStore *store, CamelFolderInfo *fi)
 {
 	g_return_if_fail (CAMEL_IS_STORE (store));
 
+	if (!fi)
+		return;
+
 	CS_CLASS (store)->free_folder_info (store, fi);
 }
 
