@@ -96,7 +96,7 @@ static void groupwise_msg_set_recipient_list (CamelMimeMessage *msg, EGwItem *it
 static void gw_update_cache ( CamelFolder *folder, GList *item_list, CamelException *ex, gboolean uid_flag);
 static CamelMimeMessage *groupwise_folder_item_to_msg ( CamelFolder *folder, EGwItem *item, CamelException *ex );
 static char* groupwise_get_filename (CamelFolder *folder, const char *uid, CamelException *ex);
-
+static const char *get_from_from_org (EGwItemOrganizer *org);
 
 #define d(x)  
 
@@ -187,6 +187,8 @@ groupwise_folder_get_message( CamelFolder *folder, const char *uid, CamelExcepti
 	cnc = cnc_lookup (priv);
 	
 	status = e_gw_connection_get_item (cnc, container_id, uid, GET_ITEM_VIEW_WITH_CACHE, &item);
+	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+		status = e_gw_connection_get_item (cnc, container_id, uid, GET_ITEM_VIEW_WITH_CACHE, &item);
 	if (status != E_GW_CONNECTION_STATUS_OK) {
 		g_free (container_id);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Could not get message"));
@@ -284,6 +286,10 @@ groupwise_populate_msg_body_from_item (EGwConnection *cnc, CamelMultipart *multi
 			status = e_gw_connection_get_attachment (cnc, 
 					e_gw_item_get_msg_body_id (item), 0, -1, 
 					(const char **)&temp_body, &len);
+			if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+				status = e_gw_connection_get_attachment (cnc, 
+					e_gw_item_get_msg_body_id (item), 0, -1, 
+					(const char **)&temp_body, &len);
 			if (status != E_GW_CONNECTION_STATUS_OK) {
 				g_warning ("Could not get Messagebody\n");
 			}
@@ -420,20 +426,14 @@ groupwise_msg_set_recipient_list (CamelMimeMessage *msg, EGwItem *item)
 
 	if (org) {
 		if (org->display_name && org->display_name[0] && org->email != NULL && org->email[0] != '\0') {
-				int i;
-				for (i = 0; org->display_name[i] != '<' && 
-						org->display_name[i] != '\0';
-						i++);
-
-				org->display_name[i] = '\0';
-		}
-		if (org->display_name && org->email) 
+			org->display_name = g_strdelimit (org->display_name, "<>", ' ');
 			ha=camel_header_address_new_name(org->display_name, org->email);
+		} else if (org->email) 
+			ha=camel_header_address_new_name(org->email, org->email);
 		else if (org->display_name)
 			ha=camel_header_address_new_group(org->display_name);
 		else
 			ha = NULL;
-
 		if (ha) {
 			subs_email = camel_header_address_list_encode (ha);	
 			camel_medium_set_header (CAMEL_MEDIUM (msg), "From", subs_email);
@@ -562,6 +562,7 @@ update_junk_list (CamelStore *store, CamelMessageInfo *info, int flag)
 	CamelGroupwiseStore *gw_store= CAMEL_GROUPWISE_STORE(store);
 	CamelGroupwiseStorePrivate  *priv = gw_store->priv;
 	EGwConnection *cnc = cnc_lookup (priv);
+	EGwConnectionStatus status;
 
 	if (!(from = g_strdup (camel_message_info_from (info))))
 		goto error;
@@ -578,12 +579,19 @@ update_junk_list (CamelStore *store, CamelMessageInfo *info, int flag)
 	if (!email || !email[index])
 		goto error;
 
-	if (flag == ADD_JUNK_ENTRY)
-		e_gw_connection_create_junk_entry (cnc, email[index], "email", "junk");
-	else if (flag == REMOVE_JUNK_ENTRY) {
+	if (flag == ADD_JUNK_ENTRY) {
+		status = e_gw_connection_create_junk_entry (cnc, email[index], "email", "junk");
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_create_junk_entry (cnc, email[index], "email", "junk");
+		
+	} else if (flag == REMOVE_JUNK_ENTRY) {
 		GList *list = NULL;
 		EGwJunkEntry *entry;
-		if (e_gw_connection_get_junk_entries (cnc, &list)== E_GW_CONNECTION_STATUS_OK){
+		status = e_gw_connection_get_junk_entries (cnc, &list);
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_get_junk_entries (cnc, &list);
+
+		if (status == E_GW_CONNECTION_STATUS_OK){
 			while (list) {
 				entry = list->data;
 				if (!g_ascii_strcasecmp (entry->match, email[index])) { 
@@ -656,6 +664,30 @@ groupwise_sync_summary (CamelFolder *folder, CamelException *ex)
 	camel_store_summary_save ((CamelStoreSummary *)((CamelGroupwiseStore *)folder->parent_store)->summary);
 }
 
+static void
+sync_flags (CamelFolder *folder, GList *uids)
+{
+	GList *l;
+	CamelMessageInfo *info = NULL;
+	CamelGroupwiseMessageInfo *gw_info;
+
+	for (l = uids; l != NULL; l = g_list_next (l)) 
+	{
+		info = camel_folder_summary_uid (folder->summary, l->data);
+		gw_info = (CamelGroupwiseMessageInfo *) info;
+
+		if (!info)
+			continue;
+	
+		gw_info->info.flags &= ~CAMEL_MESSAGE_FOLDER_FLAGGED;
+		gw_info->info.dirty = 1;
+		gw_info->server_flags = gw_info->info.flags;
+		camel_folder_summary_touch (folder->summary);
+
+		camel_message_info_free (info);
+	}
+}
+
 /* This may need to be reorganized. */
 static void
 groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
@@ -742,10 +774,6 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 			} else {
 				const char *uid;
 
-				gw_info->info.flags &= ~CAMEL_MESSAGE_FOLDER_FLAGGED;
-				gw_info->info.dirty = 1;
-				camel_folder_summary_touch (folder->summary);
-				gw_info->server_flags = gw_info->info.flags;
 				uid = camel_message_info_uid (info);
 				if (diff.bits & CAMEL_MESSAGE_DELETED) {
 
@@ -777,12 +805,16 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 							and errors are not returned always either */
 
 							status = e_gw_connection_mark_read (cnc, deleted_read_items);
+							if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+								status = e_gw_connection_mark_read (cnc, deleted_read_items);
 							g_list_free (deleted_read_items);
 							deleted_read_items = NULL;
 						}
 
 						/* And now delete the messages */
 						status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
+						if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+							status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
 						CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 						if (status == E_GW_CONNECTION_STATUS_OK) {
 							char *uid;
@@ -816,8 +848,12 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 		CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
 		if (!strcmp (folder->full_name, "Trash")) {
 			status = e_gw_connection_purge_selected_items (cnc, deleted_items);
+			if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+				status = e_gw_connection_purge_selected_items (cnc, deleted_items);
 		} else {
 			status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
+			if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+				status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
 		}
 		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		if (status == E_GW_CONNECTION_STATUS_OK) {
@@ -838,16 +874,30 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 
 	if (read_items) {
 		CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
-		e_gw_connection_mark_read (cnc, read_items);
-		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
+		status = e_gw_connection_mark_read (cnc, read_items);
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_mark_read (cnc, read_items);
+		
+		if (status == E_GW_CONNECTION_STATUS_OK)
+			sync_flags (folder, read_items);
+
 		g_list_free (read_items);
+		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 	}
+	
+
 
 	if (unread_items) {
 		CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
-		e_gw_connection_mark_unread (cnc, unread_items);
-		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
+		status = e_gw_connection_mark_unread (cnc, unread_items);
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_mark_unread (cnc, unread_items);
+		
+		if (status == E_GW_CONNECTION_STATUS_OK)
+			sync_flags (folder, unread_items);
+
 		g_list_free (unread_items);
+		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 	}
 
 	if (expunge) {
@@ -964,7 +1014,11 @@ update_update (CamelSession *session, CamelSessionThreadMsg *msg)
 		goto end1;
 	}
 
+	camel_operation_start (NULL, _("Checking for deleted messages %s"), m->folder->name);
+
 	status = e_gw_connection_create_cursor (m->cnc, m->container_id, "id", NULL, &cursor);
+	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+		status = e_gw_connection_create_cursor (m->cnc, m->container_id, "id", NULL, &cursor);
 	if (status != E_GW_CONNECTION_STATUS_OK) {
 		g_warning ("ERROR update update\n");
 		goto end1;
@@ -1030,10 +1084,12 @@ update_update (CamelSession *session, CamelSessionThreadMsg *msg)
 
 	g_print ("\nNumber of items in the folder: %d \n", g_list_length(items_full_list));
 	gw_update_all_items (m->folder, items_full_list, ex);
+	camel_operation_end (NULL);
 
 	return;
  end1:
 	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
+	camel_operation_end (NULL);
 	if (items_full_list) {
 		g_list_foreach (items_full_list, (GFunc)g_free, NULL);
 		g_list_free (items_full_list);
@@ -1084,7 +1140,7 @@ groupwise_refresh_info(CamelFolder *folder, CamelException *ex)
 			}
 			camel_store_summary_info_free ((CamelStoreSummary *)((CamelGroupwiseStore *)folder->parent_store)->summary, si);
 		}
-		//camel_folder_summary_save_to_db (folder->summary, ex);
+		/* camel_folder_summary_save_to_db (folder->summary, ex); */
 		camel_store_summary_save ((CamelStoreSummary *)((CamelGroupwiseStore *)folder->parent_store)->summary);
 	} else {
 		/* We probably could not get the messages the first time. (get_folder) failed???!
@@ -1117,7 +1173,7 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 
 	/* Sync-up the (un)read changes before getting updates,
 	so that the getFolderList will reflect the most recent changes too */
-	//groupwise_sync (folder, FALSE, ex);
+	/*groupwise_sync (folder, FALSE, ex);*/
 
 	if (((CamelOfflineStore *) gw_store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
 		g_warning ("In offline mode. Cannot refresh!!!\n");
@@ -1184,6 +1240,10 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 		status = e_gw_connection_get_quick_messages (cnc, container_id,
 				"peek id",
 				&t_str, "New", NULL, source, -1, &slist);
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_get_quick_messages (cnc, container_id,
+					"peek id",
+					&t_str, "New", NULL, source, -1, &slist);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
 			goto end2;
@@ -1197,7 +1257,7 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 			g_free (summary->time_string);
 
 
-		//summary->time_string = g_strdup (t_str);
+		/*summary->time_string = g_strdup (t_str);*/
 		((CamelGroupwiseSummary *) folder->summary)->time_string = g_strdup (t_str);
 		camel_folder_summary_touch (folder->summary);
 		groupwise_sync_summary (folder, ex);
@@ -1221,7 +1281,10 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 		status = e_gw_connection_get_quick_messages (cnc, container_id,
 				"peek id",
 				&t_str, "Modified", NULL, source, -1, &slist);
-
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_get_quick_messages (cnc, container_id,
+					"peek id",
+					&t_str, "Modified", NULL, source, -1, &slist);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
 			goto end3;
@@ -1243,13 +1306,12 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 		if (!check_all && slist && g_slist_length(slist) != 0)
 			check_all = TRUE;
 
+		if (gw_store->current_folder != folder)
+			groupwise_store_set_current_folder (gw_store, folder);
+
 		g_slist_free (slist);
 		slist = NULL;
 
-		if (gw_store->current_folder != folder) {
-			gw_store->current_folder = folder;
-		}
-		
 		if (check_all && !is_proxy) {
 				EGwContainer *container;
 				int i=0;
@@ -1272,14 +1334,15 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 
 						folder->summary->unread_count = e_gw_container_get_unread_count (container);
 						folder->summary->visible_count = e_gw_container_get_total_count (container);
+
 				} else
 					check_all = FALSE;
 				g_object_unref (container);
 		}
 
-		if (list) {
+		if (list) 
 			gw_update_cache (folder, list, ex, FALSE);
-		}
+						
 	}
 
 
@@ -1455,32 +1518,7 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 		mi->server_flags = mi->info.flags;
 
 		org = e_gw_item_get_organizer (item); 
-
-		if (org) {
-				GString *str;
-				int i;
-				str = g_string_new ("");
-
-				if (org->display_name && org->display_name[0] && org->email != NULL && org->email[0] != '\0') {
-						for (i = 0; org->display_name[i] != '<' && 
-										org->display_name[i] != '\0'; 
-										i++);
-
-						org->display_name[i] = '\0';
-						str = g_string_append (str, org->display_name);
-						str = g_string_append (str, " ");
-				}
-
-				if (org->email && org->email[0]) { 
-						g_string_append (str, "<");
-						str = g_string_append (str, org->email);
-						g_string_append (str, ">");
-				}
-
-
-				mi->info.from = camel_pstring_strdup (str->str);
-				g_string_free (str, TRUE);
-		}
+		mi->info.from = get_from_from_org (org);
 
 		g_string_truncate (str, 0);
 		recp_list = e_gw_item_get_recipient_list (item);
@@ -1580,6 +1618,37 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 	camel_folder_change_info_free (changes);
 }
 
+static const char *
+get_from_from_org (EGwItemOrganizer *org)
+{
+	const char *ret = NULL;
+
+	if (org) {
+		GString *str;
+		
+		str = g_string_new ("");
+		if (org->display_name && org->display_name[0]) {
+			org->display_name = g_strdelimit (org->display_name, "<>", ' ');
+			str = g_string_append (str, org->display_name);
+			str = g_string_append (str, " ");
+		} else if (org->email && org->email [0]) {
+			str = g_string_append (str, org->email);
+			str = g_string_append (str, " ");
+		}
+
+		if (org->email && org->email[0]) { 
+			g_string_append (str, "<");
+			str = g_string_append (str, org->email);
+			g_string_append (str, ">");
+		}
+		ret = camel_pstring_strdup (str->str);
+		g_string_free (str, TRUE);
+
+		return ret;
+	} else
+	       return camel_pstring_strdup ("");
+}
+
 /* Update summary, if there is none existing, create one */
 void
 gw_update_summary ( CamelFolder *folder, GList *list,CamelException *ex) 
@@ -1680,28 +1749,8 @@ gw_update_summary ( CamelFolder *folder, GList *list,CamelException *ex)
 		mi->server_flags = mi->info.flags;
 
 		org = e_gw_item_get_organizer (item); 
-		if (org) {
-			GString *str;
-			int i;
-			str = g_string_new ("");
-			if (org->display_name && org->display_name[0] && org->email != NULL && org->email[0] != '\0') {
-				for (i = 0; org->display_name[i] != '<' && 
-						org->display_name[i] != '\0'; 
-						i++);
+		mi->info.from = get_from_from_org (org);
 
-				org->display_name[i] = '\0';
-				str = g_string_append (str, org->display_name);
-				str = g_string_append (str, " ");
-			}
-
-			if (org->email && org->email[0]) { 
-				g_string_append (str, "<");
-				str = g_string_append (str, org->email);
-				g_string_append (str, ">");
-			}
-			mi->info.from = camel_pstring_strdup (str->str);
-			g_string_free (str, TRUE);
-		}
 		g_string_truncate (str, 0);
 		recp_list = e_gw_item_get_recipient_list (item);
 		if (recp_list) {
@@ -1802,7 +1851,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 
 	attach_list = e_gw_item_get_attach_id_list (item);
 	if (attach_list) {
-		//int attach_count = g_slist_length (attach_list);
+		/*int attach_count = g_slist_length (attach_list);*/
 		GSList *al = attach_list;
 		EGwItemAttachment *attach = (EGwItemAttachment *)al->data;
 		char *attachment = NULL;
@@ -1825,8 +1874,8 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 					g_free (attachment);
 					is_text_html = TRUE;
 				} 
-			}//if attachment and len
-		} // if Mime.822 or TEXT.htm
+			}/* if attachment and len */
+		} /* if Mime.822 or TEXT.htm */
 
 		if (!ignore_mime_822) {
 			for (al = attach_list ; al != NULL ; al = al->next) {
@@ -1879,7 +1928,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 			}
 		}
 
-	}//if attach_list
+	} /* if attach_list */
 
 
 	msg = camel_mime_message_new ();
@@ -1959,7 +2008,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 
 			if ( (attach->item_reference) && (!g_ascii_strcasecmp (attach->item_reference, "1")) ) {
 				CamelMimeMessage *temp_msg = NULL;
-				status = e_gw_connection_get_item (cnc, container_id, attach->id, "default distribution recipient message attachments subject notification created recipientStatus status startDate", &temp_item);
+				status = e_gw_connection_get_item (cnc, container_id, attach->id, GET_ITEM_VIEW_WITH_CACHE, &temp_item);
 				if (status != E_GW_CONNECTION_STATUS_OK) {
 					g_warning ("Could not get attachment\n");
 					continue;
@@ -2040,7 +2089,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 						camel_mime_part_set_content_id (part, attach->contentid);
 					}
 
-					//camel_mime_part_set_filename(part, g_strdup(attach->name));
+					/*camel_mime_part_set_filename(part, g_strdup(attach->name));*/
 					if (attach->contentType) {
 						if (is_base64_encoded)
 							camel_mime_part_set_encoding (part, CAMEL_TRANSFER_ENCODING_BASE64);
@@ -2325,6 +2374,12 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 		count = camel_folder_summary_count (destination->summary);
 
 		info = camel_folder_summary_uid (source->summary, uids->pdata[index]);
+		if (!info) {
+			g_warning ("Could not find the message: its either deleted or moved already");
+			index++;
+			continue;
+		}
+
 		gw_info = (CamelGroupwiseMessageInfo *) info;
 		if (gw_info && (gw_info->info.flags & CAMEL_MESSAGE_FOLDER_FLAGGED)) {
 			do_flags_diff (&diff, gw_info->server_flags, gw_info->info.flags);
@@ -2406,7 +2461,7 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 
 								camel_folder_summary_remove_uid (source->summary, uids->pdata[index]);
 								camel_folder_change_info_remove_uid (changes, uids->pdata[index]);
-								//}
+								/*}*/
 						}
 				} else {
 						g_warning ("Warning!! Could not move item : %s\n", (char *)uids->pdata[index]);
@@ -2426,7 +2481,7 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 	camel_folder_summary_touch (source->summary);
 	camel_folder_summary_touch (destination->summary);
 
-	gw_store->current_folder = source;
+	groupwise_store_set_current_folder (gw_store, source);
 
 	CAMEL_SERVICE_REC_UNLOCK (source->parent_store, connect_lock);
 }
@@ -2536,6 +2591,15 @@ groupwise_expunge (CamelFolder *folder, CamelException *ex)
 	camel_folder_change_info_free (changes);
 }
 
+static gint
+groupwise_cmp_uids (CamelFolder *folder, const char *uid1, const char *uid2)
+{
+	g_return_val_if_fail (uid1 != NULL, 0);
+	g_return_val_if_fail (uid2 != NULL, 0);
+
+	return strcmp (uid1, uid2);
+}
+
 static void
 camel_groupwise_folder_class_init (CamelGroupwiseFolderClass *camel_groupwise_folder_class)
 {
@@ -2549,6 +2613,7 @@ camel_groupwise_folder_class_init (CamelGroupwiseFolderClass *camel_groupwise_fo
 	camel_folder_class->rename = groupwise_folder_rename;
 	camel_folder_class->search_by_expression = groupwise_folder_search_by_expression;
 	camel_folder_class->count_by_expression = groupwise_folder_count_by_expression;
+	camel_folder_class->cmp_uids = groupwise_cmp_uids;
 	camel_folder_class->search_by_uids = groupwise_folder_search_by_uids; 
 	camel_folder_class->search_free = groupwise_folder_search_free;
 	camel_folder_class->append_message = groupwise_append_message;
@@ -2663,6 +2728,7 @@ convert_to_calendar (EGwItem *item, char **str, int *len)
 	int recur_key = 0;
 	char **tmp = NULL;
 	const char *temp = NULL;
+	const char *tmp_dt = NULL;
 
 	tmp = g_strsplit (e_gw_item_get_id (item), "@", -1);
 
@@ -2681,7 +2747,9 @@ convert_to_calendar (EGwItem *item, char **str, int *len)
 		g_string_append_printf (gstr, "UID:%s\n",e_gw_item_get_icalid (item));
 
 	g_string_append_printf (gstr, "X-GWITEM-TYPE:APPOINTMENT\n");
-	g_string_append_printf (gstr, "DTSTART:%s\n",e_gw_item_get_start_date (item));
+	tmp_dt = e_gw_item_get_start_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTSTART:%s\n", tmp_dt);
 	g_string_append_printf (gstr, "SUMMARY:%s\n", e_gw_item_get_subject (item));
 
 	temp = e_gw_item_get_message (item);
@@ -2697,7 +2765,9 @@ convert_to_calendar (EGwItem *item, char **str, int *len)
 		g_string_append(gstr, "\n");	
 	}
 
-	g_string_append_printf (gstr, "DTSTAMP:%s\n", e_gw_item_get_creation_date (item));
+	tmp_dt = e_gw_item_get_creation_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTSTAMP:%s\n", tmp_dt);
 	g_string_append_printf (gstr, "X-GWMESSAGEID:%s\n", e_gw_item_get_id (item));
 	g_string_append_printf (gstr, "X-GWSHOW-AS:BUSY\n");
 	g_string_append_printf (gstr, "X-GWRECORDID:%s\n", tmp[0]);
@@ -2719,7 +2789,9 @@ convert_to_calendar (EGwItem *item, char **str, int *len)
 		}
 	}
 
-	g_string_append_printf (gstr, "DTEND:%s\n", e_gw_item_get_end_date (item));
+	tmp_dt = e_gw_item_get_end_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTEND:%s\n", tmp_dt);
 
 	temp = NULL;
 	temp = e_gw_item_get_place (item);
@@ -2759,6 +2831,7 @@ convert_to_task (EGwItem *item, char **str, int *len)
 	GString *gstr = g_string_new (NULL);
 	char **tmp = NULL;
 	const char *temp = NULL;
+	const char *tmp_dt = NULL;
 
 	tmp = g_strsplit (e_gw_item_get_id (item), "@", -1);
 
@@ -2766,7 +2839,9 @@ convert_to_task (EGwItem *item, char **str, int *len)
 	gstr = g_string_append (gstr, "METHOD:REQUEST\n");
 	gstr = g_string_append (gstr, "BEGIN:VTODO\n");
 	g_string_append_printf (gstr, "UID:%s\n",e_gw_item_get_icalid (item));
-	g_string_append_printf (gstr, "DTSTART:%s\n",e_gw_item_get_start_date (item));
+	tmp_dt = e_gw_item_get_start_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTSTART:%s\n", tmp_dt);
 	g_string_append_printf (gstr, "SUMMARY:%s\n", e_gw_item_get_subject (item));
 
 	temp = e_gw_item_get_message (item);
@@ -2783,7 +2858,9 @@ convert_to_task (EGwItem *item, char **str, int *len)
 	}
 	temp = NULL;
 
-	g_string_append_printf (gstr, "DTSTAMP:%s\n", e_gw_item_get_creation_date (item));
+	tmp_dt = e_gw_item_get_creation_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTSTAMP:%s\n", tmp_dt);
 	g_string_append_printf (gstr, "X-GWMESSAGEID:%s\n", e_gw_item_get_id (item));
 	g_string_append_printf (gstr, "X-GWSHOW-AS:BUSY\n");
 	g_string_append_printf (gstr, "X-GWRECORDID:%s\n", tmp[0]);
@@ -2805,7 +2882,9 @@ convert_to_task (EGwItem *item, char **str, int *len)
 		}
 	}
 
-	g_string_append_printf (gstr, "DTEND:%s\n", e_gw_item_get_end_date (item));
+	tmp_dt = e_gw_item_get_end_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTEND:%s\n", tmp_dt);
 
 	temp = e_gw_item_get_place (item);
 	if (temp)
@@ -2838,6 +2917,7 @@ convert_to_note (EGwItem *item, char **str, int *len)
 	GString *gstr = g_string_new (NULL);
 	char **tmp = NULL;
 	const char *temp = NULL;
+	const char *tmp_dt = NULL;
 
 	tmp = g_strsplit (e_gw_item_get_id (item), "@", -1);
 
@@ -2845,7 +2925,9 @@ convert_to_note (EGwItem *item, char **str, int *len)
 	gstr = g_string_append (gstr, "METHOD:PUBLISH\n");
 	gstr = g_string_append (gstr, "BEGIN:VJOURNAL\n");
 	g_string_append_printf (gstr, "UID:%s\n",e_gw_item_get_icalid (item));
-	g_string_append_printf (gstr, "DTSTART:%s\n",e_gw_item_get_start_date (item));
+	tmp_dt = e_gw_item_get_start_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTSTART:%s\n", tmp_dt);
 	g_string_append_printf (gstr, "SUMMARY:%s\n", e_gw_item_get_subject (item));
 
 	temp = e_gw_item_get_message (item);
@@ -2862,7 +2944,9 @@ convert_to_note (EGwItem *item, char **str, int *len)
 	}
 	temp = NULL;
 
-	g_string_append_printf (gstr, "DTSTAMP:%s\n", e_gw_item_get_creation_date (item));
+	tmp_dt = e_gw_item_get_creation_date (item);
+	if (tmp_dt)
+		g_string_append_printf (gstr, "DTSTAMP:%s\n", tmp_dt);
 	g_string_append_printf (gstr, "X-GWMESSAGEID:%s\n", e_gw_item_get_id (item));
 	g_string_append_printf (gstr, "X-GWRECORDID:%s\n", tmp[0]);
 
