@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2002 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Parthasarathi Susarla <sparthasrathi@novell.com>
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -39,7 +39,7 @@ typedef struct _CamelGroupwiseStoreInfo CamelGroupwiseStoreInfo;
 
 enum {
 	CAMEL_GW_STORE_INFO_FULL_NAME = CAMEL_STORE_INFO_LAST,
-	CAMEL_GW_STORE_INFO_LAST,
+	CAMEL_GW_STORE_INFO_LAST
 };
 
 struct _CamelGroupwiseStoreInfo {
