@@ -40,7 +40,7 @@ typedef struct _CamelGroupwiseMessageContentInfo CamelGroupwiseMessageContentInf
 /* extra summary flags*/
 enum {
 	CAMEL_GW_MESSAGE_JUNK = 1<<17,
-	CAMEL_GW_MESSAGE_NOJUNK = 1<<18,
+	CAMEL_GW_MESSAGE_NOJUNK = 1<<18
 };
 
 struct _CamelGroupwiseMessageInfo {
