@@ -2201,7 +2201,7 @@ rename_folder (CamelStore *store, const char *old_name, const char *new_name_in,
 	/* So do we care if this didn't work?  Its just a cache? */
 	if (g_rename (oldpath, newpath) == -1) {
 		g_warning ("Could not rename message cache '%s' to '%s': %s: cache reset",
-			   oldpath, newpath, strerror (errno));
+			   oldpath, newpath, g_strerror (errno));
 	}
 	
 	g_free (oldpath);
@@ -3000,8 +3000,6 @@ camel_imap_store_connected (CamelImapStore *store, CamelException *ex)
 }
 
 
-/* FIXME: please god, when will the hurting stop? Thus function is so
-   fucking broken it's not even funny. */
 ssize_t
 camel_imap_store_readline (CamelImapStore *store, char **dest, CamelException *ex)
 {
@@ -3033,16 +3031,14 @@ camel_imap_store_readline (CamelImapStore *store, char **dest, CamelException *e
 	}
 
 	if (nread <= 0) {
-		if (errno == EINTR) {
+		if (errno == EINTR)
 			camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Operation cancelled"));
-		} else {
+		else
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
 					      _("Server unexpectedly disconnected: %s"),
 					      g_strerror (errno));
 		
-			camel_service_disconnect (CAMEL_SERVICE (store), FALSE, NULL);
-		}
-
+		camel_service_disconnect (CAMEL_SERVICE (store), FALSE, NULL);
 		g_byte_array_free (ba, TRUE);
 		return -1;
 	}
