@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Ximian Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors:
  *    Michael Zucchi <notzed@ximian.com>
@@ -40,7 +40,7 @@
 G_BEGIN_DECLS
 
 enum {
-	CAMEL_IMAP_MESSAGE_RECENT = 1<<17,
+	CAMEL_IMAP_MESSAGE_RECENT = 1<<17
 };
 
 typedef struct _CamelImapSummaryClass CamelImapSummaryClass;
