@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Camel
- *  Copyright (C) 1999-2007 Novell, Inc. (www.novell.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Jeffrey Stedfast <fejj@novell.com>
  *           Michael Zucchi <notzed@novell.com>
@@ -24,10 +24,9 @@
 #ifndef __CAMEL_IMAP4_SEARCH_H__
 #define __CAMEL_IMAP4_SEARCH_H__
 
-#include <libedataserver/e-msgport.h>
-
 #include <camel/camel-data-cache.h>
 #include <camel/camel-folder-search.h>
+#include <camel/camel-list-utils.h>
 
 #define CAMEL_IMAP4_SEARCH_TYPE         (camel_imap4_search_get_type ())
 #define CAMEL_IMAP4_SEARCH(obj)         CAMEL_CHECK_CAST (obj, camel_imap4_search_get_type (), CamelIMAP4Search)
@@ -43,23 +42,23 @@ struct _CamelIMAP4Engine;
 
 struct _CamelIMAP4Search {
 	CamelFolderSearch parent_object;
-
+	
 	struct _CamelIMAP4Engine *engine;
-
+	
 	guint32 lastuid;	/* current 'last uid' for the folder */
 	guint32 validity;	/* validity of the current folder */
-
+	
 	CamelDataCache *cache;	/* disk-cache for searches */
-
+	
 	/* cache of body search matches */
-	EDList matches;
+	CamelDList matches;
 	GHashTable *matches_hash;
 	unsigned int matches_count;
 };
 
 struct _CamelIMAP4SearchClass {
 	CamelFolderSearchClass parent_class;
-
+	
 };
 
 
