@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -40,7 +40,7 @@ typedef enum _e_account_find_t {
 	E_ACCOUNT_FIND_UID,
 	E_ACCOUNT_FIND_ID_NAME,
 	E_ACCOUNT_FIND_ID_ADDRESS,
-	E_ACCOUNT_FIND_PARENT_UID,
+	E_ACCOUNT_FIND_PARENT_UID
 } e_account_find_t;
 
 typedef struct _EAccountList {
