@@ -44,7 +44,7 @@ static guint signals[LAST_SIGNAL];
 
 static void finalize (GObject *);
 
-G_DEFINE_TYPE (EAccount, e_account, G_TYPE_OBJECT);
+G_DEFINE_TYPE (EAccount, e_account, G_TYPE_OBJECT)
 
 /*
 lock mail accounts	Relatively difficult -- involves redesign of the XML blobs which describe accounts
@@ -282,7 +282,7 @@ str_to_receipt_policy (const xmlChar *str)
 static xmlChar*
 receipt_policy_to_str (EAccountReceiptPolicy val)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	switch (val) {
 	case E_ACCOUNT_RECEIPT_NEVER:
@@ -361,7 +361,7 @@ xml_set_identity (xmlNodePtr node, EAccountIdentity *id)
 			changed |= xml_set_prop (node, "uid", &id->sig_uid);
 			if (!id->sig_uid) {
 
-				/* WTF is this shit doing here?  Migrate is supposed to "handle this" */
+				/* XXX Migrate is supposed to "handle this" */
 
 				/* set a fake sig uid so the migrate code can handle this */
 				gboolean autogen = FALSE;
@@ -726,7 +726,7 @@ enum {
 	EAP_LOCK_DEFAULT_FOLDERS,
 	EAP_LOCK_SAVE_PASSWD,
 	EAP_LOCK_SOURCE,
-	EAP_LOCK_TRANSPORT,
+	EAP_LOCK_TRANSPORT
 };
 
 static struct _system_info {
@@ -807,7 +807,7 @@ static GHashTable *ea_system_table;
 static guint32 ea_perms;
 
 static struct _option_info {
-	char *key;
+	const char *key;
 	guint32 perms;
 } ea_option_list[] = {
 	{ "imap_use_lsub", 1<<EAP_IMAP_SUBSCRIBED },
@@ -822,7 +822,7 @@ static struct _option_info {
 #define LOCK_BASE "/apps/evolution/lock/mail/accounts"
 
 static void
-ea_setting_notify(GConfClient *gconf, guint cnxn_id, GConfEntry *entry, void *crap)
+ea_setting_notify (GConfClient *gconf, guint cnxn_id, GConfEntry *entry, void *crap)
 {
 	GConfValue *value;
 	char *tkey;
@@ -846,7 +846,7 @@ ea_setting_notify(GConfClient *gconf, guint cnxn_id, GConfEntry *entry, void *cr
 }
 
 static void
-ea_setting_setup(void)
+ea_setting_setup (void)
 {
 	GConfClient *gconf = gconf_client_get_default();
 	GConfEntry *entry;
@@ -859,7 +859,7 @@ ea_setting_setup(void)
 
 	ea_option_table = g_hash_table_new(g_str_hash, g_str_equal);
 	for (i=0;i<sizeof(ea_option_list)/sizeof(ea_option_list[0]);i++)
-		g_hash_table_insert(ea_option_table, ea_option_list[i].key, &ea_option_list[i]);
+		g_hash_table_insert(ea_option_table, (gpointer) ea_option_list[i].key, &ea_option_list[i]);
 
 	gconf_client_add_dir(gconf, LOCK_BASE, GCONF_CLIENT_PRELOAD_NONE, NULL);
 
@@ -889,24 +889,30 @@ ea_setting_setup(void)
 	(((char **)(((char *)ea)+account_info[type].offset))[0] + account_info[type].struct_offset): \
 	(((char *)ea)+account_info[type].offset))
 
-const char *e_account_get_string(EAccount *ea, e_account_item_t type)
+const char*
+e_account_get_string (EAccount *ea, e_account_item_t type)
 {
+	g_return_val_if_fail (ea != NULL, NULL);
 	return *((const char **)addr(ea, type));
 }
 
-int e_account_get_int(EAccount *ea, e_account_item_t type)
+int
+e_account_get_int (EAccount *ea, e_account_item_t type)
 {
+	g_return_val_if_fail (ea != NULL, 0);
 	return *((int *)addr(ea, type));
 }
 
-gboolean e_account_get_bool(EAccount *ea, e_account_item_t type)
+gboolean
+e_account_get_bool (EAccount *ea, e_account_item_t type)
 {
+	g_return_val_if_fail (ea != NULL, FALSE);
 	return *((gboolean *)addr(ea, type));
 }
 
 #if d(!)0
 static void
-dump_account(EAccount *ea)
+dump_account (EAccount *ea)
 {
 	char *xml;
 
@@ -918,9 +924,12 @@ dump_account(EAccount *ea)
 #endif
 
 /* TODO: should it return true if it changed? */
-void e_account_set_string(EAccount *ea, e_account_item_t type, const char *val)
+void
+e_account_set_string (EAccount *ea, e_account_item_t type, const char *val)
 {
 	char **p;
+	
+	g_return_if_fail (ea != NULL);
 
 	if (!e_account_writable(ea, type)) {
 		g_warning("Trying to set non-writable option account value");
@@ -937,8 +946,11 @@ void e_account_set_string(EAccount *ea, e_account_item_t type, const char *val)
 	}
 }
 
-void e_account_set_int(EAccount *ea, e_account_item_t type, int val)
+void
+e_account_set_int (EAccount *ea, e_account_item_t type, int val)
 {
+	g_return_if_fail (ea != NULL);
+	
 	if (!e_account_writable(ea, type)) {
 		g_warning("Trying to set non-writable option account value");
 	} else {
@@ -952,8 +964,11 @@ void e_account_set_int(EAccount *ea, e_account_item_t type, int val)
 	}
 }
 
-void e_account_set_bool(EAccount *ea, e_account_item_t type, gboolean val)
+void
+e_account_set_bool (EAccount *ea, e_account_item_t type, gboolean val)
 {
+	g_return_if_fail (ea != NULL);
+	
 	if (!e_account_writable(ea, type)) {
 		g_warning("Trying to set non-writable option account value");
 	} else {
@@ -968,7 +983,7 @@ void e_account_set_bool(EAccount *ea, e_account_item_t type, gboolean val)
 }
 
 gboolean
-e_account_writable_option(EAccount *ea, const char *protocol, const char *option)
+e_account_writable_option (EAccount *ea, const char *protocol, const char *option)
 {
 	char *key;
 	struct _option_info *info;
@@ -991,7 +1006,7 @@ e_account_writable_option(EAccount *ea, const char *protocol, const char *option
 }
 
 gboolean
-e_account_writable(EAccount *ea, e_account_item_t type)
+e_account_writable (EAccount *ea, e_account_item_t type)
 {
 	ea_setting_setup();
 
