@@ -3,7 +3,7 @@
  * Authors:
  *   Christopher James Lahey <clahey@umich.edu>
  *
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #include <config.h>
@@ -12,9 +12,6 @@
 #include "e-list.h"
 
 
-static void        e_list_iterator_init       (EListIterator *list);
-static void        e_list_iterator_class_init (EListIteratorClass *klass);
-
 static void        e_list_iterator_invalidate (EIterator *iterator);
 static gboolean    e_list_iterator_is_valid   (EIterator *iterator);
 static void        e_list_iterator_set        (EIterator  *iterator,
@@ -30,7 +27,7 @@ static void        e_list_iterator_last       (EIterator *iterator);
 static const void *e_list_iterator_get        (EIterator *iterator);
 static void        e_list_iterator_dispose    (GObject *object);
 
-G_DEFINE_TYPE(EListIterator, e_list_iterator, E_TYPE_ITERATOR);
+G_DEFINE_TYPE(EListIterator, e_list_iterator, E_TYPE_ITERATOR)
 
 static void
 e_list_iterator_class_init (EListIteratorClass *klass)
