@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* e-source.c
  *
- * Copyright (C) 2003  Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -72,7 +72,7 @@ group_weak_notify (ESource *source,
 
 /* GObject methods.  */
 
-G_DEFINE_TYPE (ESource, e_source, G_TYPE_OBJECT);
+G_DEFINE_TYPE (ESource, e_source, G_TYPE_OBJECT)
 
 static void
 impl_finalize (GObject *object)
@@ -218,33 +218,6 @@ e_source_new_from_xml_node (xmlNodePtr node)
 	return NULL;
 }
 
-gboolean
-e_source_equal (ESource *source_1, ESource *source_2)
-{
-	gboolean equal = FALSE;
-
-	g_return_val_if_fail (E_IS_SOURCE (source_1), FALSE);
-	g_return_val_if_fail (E_IS_SOURCE (source_2), FALSE);
-
-	if (source_1->priv->uid && source_2->priv->uid &&
-	    !strcmp (source_1->priv->uid, source_2->priv->uid)) {
-		equal = TRUE;
-	} else {
-		gchar *uri_1, *uri_2;
-
-		uri_1 = e_source_get_uri (source_1);
-		uri_2 = e_source_get_uri (source_2);
-
-		if (uri_1 && uri_2 && !strcmp (uri_1, uri_2))
-			equal = TRUE;
-
-		g_free (uri_1);
-		g_free (uri_2);
-	}
-
-	return equal;
-}
-
 static void
 import_properties (ESource *source,
 		   xmlNodePtr prop_root)
@@ -564,6 +537,7 @@ e_source_set_readonly (ESource  *source,
 
 }
 
+#ifndef EDS_DISABLE_DEPRECATED
 void
 e_source_set_color (ESource *source,
 		    guint32 color)
@@ -583,6 +557,7 @@ e_source_unset_color (ESource *source)
 
 	e_source_set_color_spec (source, NULL);
 }
+#endif
 
 /**
  * e_source_set_color_spec:
@@ -673,6 +648,7 @@ e_source_get_readonly (ESource *source)
 }
 
 
+#ifndef EDS_DISABLE_DEPRECATED
 /**
  * e_source_get_color:
  * @source: An ESource
@@ -706,6 +682,7 @@ e_source_get_color (ESource *source,
 
 	return TRUE;
 }
+#endif
 
 char *
 e_source_get_uri (ESource *source)
@@ -817,6 +794,88 @@ e_source_to_standalone_xml (ESource *source)
 	return returned_buffer;
 }
 
+/**
+ * e_source_equal:
+ * @a: An ESource
+ * @b: Another ESource
+ *
+ * Compares if @a is equivalent to @b.
+ *
+ * Return value: %TRUE if @a is equivalent to @b, 
+ * %FALSE otherwise.
+ **/
+gboolean 
+e_source_equal (ESource *a, ESource *b)
+{
+	g_return_val_if_fail (E_IS_SOURCE (a), FALSE); 
+	g_return_val_if_fail (E_IS_SOURCE (b), FALSE); 
+
+	#define ONLY_ONE_NULL(aa, bb) (((aa) == NULL && (bb) != NULL) || ((aa) != NULL && (bb) == NULL))
+
+	/* Compare source stuff */
+	if (a->priv->uid 
+	 && b->priv->uid 
+	 && g_ascii_strcasecmp (a->priv->uid, b->priv->uid))
+		return FALSE; 
+
+	if (a->priv->name 
+	 && b->priv->name 
+	 && g_ascii_strcasecmp (a->priv->name, b->priv->name))
+		return FALSE; 
+
+	if (a->priv->relative_uri 
+	 && b->priv->relative_uri 
+	 && g_ascii_strcasecmp (a->priv->relative_uri, b->priv->relative_uri))
+		return FALSE; 
+
+	if (a->priv->absolute_uri 
+	 && b->priv->absolute_uri 
+	 && g_ascii_strcasecmp (a->priv->absolute_uri, b->priv->absolute_uri))
+		return FALSE; 
+
+	if ((a->priv->color_spec 
+	 && b->priv->color_spec 
+	 && g_ascii_strcasecmp (a->priv->color_spec, b->priv->color_spec)) ||
+	 (ONLY_ONE_NULL (a->priv->color_spec, b->priv->color_spec)))
+		return FALSE; 
+
+	if (a->priv->readonly != b->priv->readonly)
+		return FALSE; 
+
+	if (!compare_str_hashes (a->priv->properties, b->priv->properties))
+		return FALSE; 
+
+	#undef ONLY_ONE_NULL
+
+	return TRUE; 
+}
+
+/**
+ * e_source_xmlstr_equal:
+ * @a: XML representation of an ESource
+ * @b: XML representation of another ESource
+ *
+ * Compares if @a is equivalent to @b.
+ *
+ * Return value: %TRUE if @a is equivalent to @b, 
+ * %FALSE otherwise.
+ **/
+gboolean 
+e_source_xmlstr_equal (const gchar *a, const gchar *b)
+{
+	ESource *srca, *srcb; 
+	gboolean retval; 
+
+	srca = e_source_new_from_standalone_xml (a); 
+	srcb = e_source_new_from_standalone_xml (b); 
+
+	retval = e_source_equal (srca, srcb); 
+
+	g_object_unref (srca); 
+	g_object_unref (srcb); 
+
+	return retval; 
+}
 
 ESource *
 e_source_new_from_standalone_xml (const char *xml)
